summaryrefslogtreecommitdiff
path: root/guix/system-create.scm
diff options
context:
space:
mode:
Diffstat (limited to 'guix/system-create.scm')
-rw-r--r--guix/system-create.scm6
1 files changed, 3 insertions, 3 deletions
diff --git a/guix/system-create.scm b/guix/system-create.scm
index 212a7a7..6102105 100644
--- a/guix/system-create.scm
+++ b/guix/system-create.scm
@@ -81,7 +81,7 @@
(service block-facebook-hosts-service-type)
(simple-service 'add-extra-hosts
hosts-service-type
- (list (host "192.168.0.100" "zeus"
+ (list (host "192.168.0.100" "constantine"
'())
(host "192.168.0.101" "uranus"
'())))
@@ -130,8 +130,8 @@
(cpu-boost-on-ac? #t)
(wifi-pwr-on-bat? #t))))
- ;; Services specifics for zeus
- (if (string= hostname "zeus")
+ ;; Services specifics for constantine
+ (if (string= hostname "constantine")
(list
(service oci-container-service-type
(list